n1 computes the stage one sample size of an optimal adaptive design
1 | n1(parameters, lambda1, lambda2)
|
parameters |
The parameters (alpha, power, standardized effect) whith which you want to build your design |
lambda1, lambda2 |
The Lagrange penalization parameters |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.