opt_alpha: Compute the type I error rate of a design

Description Usage Arguments

Description

opt_alpha gives the type I error rate of a design.

Usage

1

Arguments

d

An object of class design.


MatheMax/OptReSample documentation built on May 5, 2019, 8:14 a.m.