Description Usage Arguments Details Value
optimal_design returns an optimal two-stage adaptive design.
1 2 | optimal_design(effect, alpha, pow, effect_null = 0, sd = 1,
standardized = T, t_approx = F, lagrange = T)
|
effect |
The effect on that the power is computed |
alpha |
The maximal type I error rate |
pow |
The minimal power |
effect_null |
The effect under the null hypothesis. Default is 0. |
sd |
The standard deviation. Default is 1. |
standardized |
Logical. Is |
t_approx |
Logical. Should a t-approximation be used? Default is |
lagrange |
Logical. Should a Lagrangian procedure be used? Default is |
The optimality criterion is given as the expected sample size under the alternative hypothesis.
If standardized=T, the values of effect_null and sd are set to their default,
even if they were specified differently.
The use of a t-approximation (t_approx=T) or a Lagrangian approach (lagrange=T) yields more precise results,
but makes the calculation slowlier.
Note that there is no Lagrangian implementation of the t-approximation. Hence, the value of lagrange will be
ignored, if t_approx is set to T.
An object of class design
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.