optimal_gsd: Compute the optimal group sequential design

Description Usage Arguments

Description

optimal_gsd computes the group sequential design that is optimal w.r.t. expected sample size under the alternative hypothesis and holdes presepcified type I and type II error constraints.

Usage

1

Arguments

parameters

Parameters specifying the design


MatheMax/OptReSample documentation built on May 5, 2019, 8:14 a.m.