Description Usage Arguments Details
plot_power plots the power curve for the true effect.
1 | plot_power(d, parameters)
|
d |
An object of class |
parameters |
Parameters speficying the situation. See parameters for details. |
The true effect size has to be specified in parameters as well as type I - and type II - error constraints.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.