optimal_gsd computes the group sequential design that is optimal w.r.t. expected sample size under the
alternative hypothesis and holdes presepcified type I and type II error constraints.
1 |
parameters |
Parameters specifying the design |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.